@@ -1,22 +1,6 @@
-use std::ffi::c_void;
 use tokio::io::{AsyncReadExt, AsyncWriteExt};
 use winspawn::{move_fd, spawn, FileDescriptor, Mode};
 
-type HANDLE = *mut c_void;
-
-#[cfg(windows)]
-fn into_raw_handle<P>(p: P) -> HANDLE
-where
-    P: std::os::windows::io::IntoRawHandle,
-{
-    p.into_raw_handle()
-}
-
-#[cfg(not(windows))]
-fn into_raw_handle<P>(_: P) -> HANDLE {
-    panic!("stub")
-}
-
 #[tokio::test]
 async fn test_simple() {
     pretty_env_logger::init();
@@ -26,9 +10,6 @@ async fn test_simple() {
     eprintln!("{:?}", rxtheir);
     eprintln!("{:?}", txtheir);
 
-    let rxtheir = into_raw_handle(rxtheir);
-    let txtheir = into_raw_handle(txtheir);
-
     let rxtheir = FileDescriptor::from_raw_handle(rxtheir, Mode::ReadOnly).unwrap();
     let txtheir = FileDescriptor::from_raw_handle(txtheir, Mode::ReadWrite).unwrap();
 
